# <img src='https://raw.githack.com/FortAwesome/Font-Awesome/master/svgs/solid/info-circle.svg' card_color='#22a7f0' width='50' height='50' style='vertical-align:bottom'/> System Diagnostics
Retrieve system information such as CPU, memory, and language settings.

## About
The **System Diagnostics Skill** provides various system metrics, including kernel version, CPU and memory usage, GPU availability, and language settings. Users can query these details via voice commands.

## Examples
* "What is your kernel version?"
* "Do you have a GPU?"
* "What is your CPU usage?"
* "How much memory are you using?"
* "What language are you using?"

## Category
**System**

## Tags
#system
#diagnostics
#hardware
#performance
#language

## Credits

<img src="img.png" width="128"/>

> This skill was funded by the Ministerio para la Transformación Digital y de la Función Pública and Plan de Recuperación, Transformación y Resiliencia - Funded by EU – NextGenerationEU within the framework of the project ILENIA with reference 2022/TL22/00215337
